Plotting rashba spin splitting — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

Note

Go to the end to download the full example code.

# Plotting rashba spin splitting

Plotting rashba spin splitting example. From our first paper we had an example to plot the different spin texture projections of BiSb at a constant energy surface 0.60eV above the fermei level and -0.90ev below the fermi level.

First download the example files with the code below. Then replace data_dir below.

Downloading example

     data_dir = pyprocar.download_example(save_dir='',
                                 material='BiSb_monolayer',
                                 code='vasp',
                                 spin_calc_type='non-colinear',
                                 calc_type='fermi')

importing pyprocar and specifying local data_dir

    import os

    import pyprocar

    data_dir = os.path.join(
        pyprocar.utils.DATA_DIR,
        "examples",
        "BiSb_monolayer",
        "vasp",
        "non-colinear",
        "fermi",
    )

## energy = 0.60 sx projection no arrows

    pyprocar.fermi2D(
        code="vasp",
        dirname=data_dir,
        energy=0.60,
        fermi=-1.1904,
        spin_texture=True,
        no_arrow=True,
        spin_projection="x",
        plot_color_bar=True,
    )

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

    dirname         :  Z:\data\pyprocar\data\examples\BiSb_monolayer\vasp\non-colinear\fermi
    bands           :  None
    atoms           :  None
    orbitals        :  None
    spin comp.      :  None
    energy          :  0.6
    rot. symmetry   :  1
    origin (trasl.) :  [0, 0, 0]
    rotation        :  [0, 0, 0, 1]
    save figure     :  None
    spin_texture    :  True

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , plain_bands , parametric
                --------------------------------------------------------

                WARNING : Make sure the kmesh has kz points with kz=0.0 +- 0.01
                ----------------------------------------------------------------------------------------------------------

    _____________________________________________________
    Useful band indices for spin-0 : [20 21]

## energy = 0.60 sy projection no arrows

    pyprocar.fermi2D(
        code="vasp",
        dirname=data_dir,
        energy=0.60,
        fermi=-1.1904,
        spin_texture=True,
        no_arrow=True,
        spin_projection="y",
        plot_color_bar=True,
    )

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

    dirname         :  Z:\data\pyprocar\data\examples\BiSb_monolayer\vasp\non-colinear\fermi
    bands           :  None
    atoms           :  None
    orbitals        :  None
    spin comp.      :  None
    energy          :  0.6
    rot. symmetry   :  1
    origin (trasl.) :  [0, 0, 0]
    rotation        :  [0, 0, 0, 1]
    save figure     :  None
    spin_texture    :  True

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , plain_bands , parametric
                --------------------------------------------------------

                WARNING : Make sure the kmesh has kz points with kz=0.0 +- 0.01
                ----------------------------------------------------------------------------------------------------------

    _____________________________________________________
    Useful band indices for spin-0 : [20 21]

## energy = 0.60 sz projection no arrows

    pyprocar.fermi2D(
        code="vasp",
        dirname=data_dir,
        energy=0.60,
        fermi=-1.1904,
        spin_texture=True,
        no_arrow=True,
        spin_projection="z",
        plot_color_bar=True,
    )

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

    dirname         :  Z:\data\pyprocar\data\examples\BiSb_monolayer\vasp\non-colinear\fermi
    bands           :  None
    atoms           :  None
    orbitals        :  None
    spin comp.      :  None
    energy          :  0.6
    rot. symmetry   :  1
    origin (trasl.) :  [0, 0, 0]
    rotation        :  [0, 0, 0, 1]
    save figure     :  None
    spin_texture    :  True

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , plain_bands , parametric
                --------------------------------------------------------

                WARNING : Make sure the kmesh has kz points with kz=0.0 +- 0.01
                ----------------------------------------------------------------------------------------------------------

    _____________________________________________________
    Useful band indices for spin-0 : [20 21]

## energy = -0.90 sx projection no arrows

    pyprocar.fermi2D(
        code="vasp",
        dirname=data_dir,
        energy=-0.90,
        fermi=-1.1904,
        spin_texture=True,
        no_arrow=True,
        spin_projection="x",
        plot_color_bar=True,
    )

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

    dirname         :  Z:\data\pyprocar\data\examples\BiSb_monolayer\vasp\non-colinear\fermi
    bands           :  None
    atoms           :  None
    orbitals        :  None
    spin comp.      :  None
    energy          :  -0.9
    rot. symmetry   :  1
    origin (trasl.) :  [0, 0, 0]
    rotation        :  [0, 0, 0, 1]
    save figure     :  None
    spin_texture    :  True

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , plain_bands , parametric
                --------------------------------------------------------

                WARNING : Make sure the kmesh has kz points with kz=0.0 +- 0.01
                ----------------------------------------------------------------------------------------------------------

    _____________________________________________________
    Useful band indices for spin-0 : [16 17 18 19]

## energy = -0.90 sy projection no arrows

    pyprocar.fermi2D(
        code="vasp",
        dirname=data_dir,
        energy=-0.90,
        fermi=-1.1904,
        spin_texture=True,
        no_arrow=True,
        spin_projection="y",
        plot_color_bar=True,
    )

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

    dirname         :  Z:\data\pyprocar\data\examples\BiSb_monolayer\vasp\non-colinear\fermi
    bands           :  None
    atoms           :  None
    orbitals        :  None
    spin comp.      :  None
    energy          :  -0.9
    rot. symmetry   :  1
    origin (trasl.) :  [0, 0, 0]
    rotation        :  [0, 0, 0, 1]
    save figure     :  None
    spin_texture    :  True

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , plain_bands , parametric
                --------------------------------------------------------

                WARNING : Make sure the kmesh has kz points with kz=0.0 +- 0.01
                ----------------------------------------------------------------------------------------------------------

    _____________________________________________________
    Useful band indices for spin-0 : [16 17 18 19]

## energy = -0.90 sz projection no arrows

    pyprocar.fermi2D(
        code="vasp",
        dirname=data_dir,
        energy=-0.90,
        fermi=-1.1904,
        spin_texture=True,
        no_arrow=True,
        spin_projection="z",
        plot_color_bar=True,
    )

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

    dirname         :  Z:\data\pyprocar\data\examples\BiSb_monolayer\vasp\non-colinear\fermi
    bands           :  None
    atoms           :  None
    orbitals        :  None
    spin comp.      :  None
    energy          :  -0.9
    rot. symmetry   :  1
    origin (trasl.) :  [0, 0, 0]
    rotation        :  [0, 0, 0, 1]
    save figure     :  None
    spin_texture    :  True

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , plain_bands , parametric
                --------------------------------------------------------

                WARNING : Make sure the kmesh has kz points with kz=0.0 +- 0.01
                ----------------------------------------------------------------------------------------------------------

    _____________________________________________________
    Useful band indices for spin-0 : [16 17 18 19]

## energy = 0.60 sx projection with arrows

    pyprocar.fermi2D(
        code="vasp",
        dirname=data_dir,
        energy=0.60,
        fermi=-1.1904,
        spin_texture=True,
        spin_projection="x",
        arrow_size=3,
        arrow_density=6,
        plot_color_bar=True,
    )

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

    dirname         :  Z:\data\pyprocar\data\examples\BiSb_monolayer\vasp\non-colinear\fermi
    bands           :  None
    atoms           :  None
    orbitals        :  None
    spin comp.      :  None
    energy          :  0.6
    rot. symmetry   :  1
    origin (trasl.) :  [0, 0, 0]
    rotation        :  [0, 0, 0, 1]
    save figure     :  None
    spin_texture    :  True

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , plain_bands , parametric
                --------------------------------------------------------

                WARNING : Make sure the kmesh has kz points with kz=0.0 +- 0.01
                ----------------------------------------------------------------------------------------------------------

    _____________________________________________________
    Useful band indices for spin-0 : [20 21]

## energy = -0.90 sx projection with arrows

    pyprocar.fermi2D(
        code="vasp",
        dirname=data_dir,
        energy=-0.90,
        fermi=-1.1904,
        spin_texture=True,
        spin_projection="x",
        arrow_size=3,
        arrow_density=6,
        plot_color_bar=True,
    )

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

    dirname         :  Z:\data\pyprocar\data\examples\BiSb_monolayer\vasp\non-colinear\fermi
    bands           :  None
    atoms           :  None
    orbitals        :  None
    spin comp.      :  None
    energy          :  -0.9
    rot. symmetry   :  1
    origin (trasl.) :  [0, 0, 0]
    rotation        :  [0, 0, 0, 1]
    save figure     :  None
    spin_texture    :  True

                --------------------------------------------------------
                There are additional plot options that are defined in a configuration file.
                You can change these configurations by passing the keyword argument to the function
                To print a list of plot options set print_plot_opts=True

                Here is a list modes : plain , plain_bands , parametric
                --------------------------------------------------------

                WARNING : Make sure the kmesh has kz points with kz=0.0 +- 0.01
                ----------------------------------------------------------------------------------------------------------

    _____________________________________________________
    Useful band indices for spin-0 : [16 17 18 19]

Total running time of the script: (1 minutes 3.790 seconds)

Gallery generated by Sphinx-Gallery